/* -----------------------------------------------------------------------*/
/* PCMLAB - "LOG.CMD"  STRESS Testcase - pcmmed01 Results Analyzer        */
/*                                                                        */
/*  carried on: T:\PCMLAB\STRESS\CMD  &  W:\STRESS\CMD   (LAN Server)     */
/*                                                                        */
/*  PURPOSE: Examine contents of \LOG directory;  Log results of PCMMED01 */
/*           test execution and move files to \LOGM1 directory.           */
/*                                                                        */
/*          Compress the various log files into a one-screen SUMMARY with */
/*          counts for PASS, FAIL, PARTIAL, and MISSING test results.     */
/*                                                                        */
/*  parameter PCMMED01  (opt'l) Log results for PCMMED01                  */
/*  parameter Rnnnnnnn  (opt'l) Release designation                       */
/*  parameter Q         (opt'l) quiet run, no screen displays             */
/* -----------------------------------------------------------------------*/
'cls'
say ''

parse arg arglist    /*-- This form leaves parms in mixed case as entered --*/
logtest = ''
release = 0          /* set defaults for optional parameters */
quiet = 0
do while (arglist \= '')                  /* 'CASE' logic is controlled by  */
   parse var arglist parm remainder       /* first letter of each parameter */
   arglist = remainder
   code = left(parm,1)
   if code = '?' then signal INFO_PLEASE
   if pos(code,'Qq') >0  then quiet = 1
   else
      if parm = 'PCMMED01' then logtest = 'PCMMED01'
   else
      if parm = 'pcmmed01' then logtest = 'PCMMED01'
   else
      if pos(code,'Rr') > 0 then release = parm
   else
      if pos(code,'Bb') > 0 then bay = parm
   else
      if code \= '' then do
         say 'Parameter "'parm'" not used; enter "?" to see full parm list:'
         pull y
         if y = '?' then signal INFO_PLEASE
         end
end

if quiet then 'echo off'


if (release = 0) then do
   rellvl  = value('PCM_RELLVL',,'OS2ENVIRONMENT');    /* get release level  */
   release = 'R'||rellvl
   end
Orelease = right(release,length(release) -1);
Obay = bay

/*--------------------------------------------*/
/*--CALL ROUTINE to analyse PCMMED01 results--*/
/*--------------------------------------------*/
logtest = 'PCMMED01'

call LOG_MED01;

exit


/***************************/
/*    MED01 LOG SECTION    */
/***************************/
LOG_MED01:
procedure expose release Orelease Obay
missing = 0;
passed = 0;
failed = 0;
partial = 0;
time_start = '';
time_end = '';
date_start = '';
date_end = '';
summary='PCMMED01.SUM';

'erase pcmmed01.sum'

'grep "DSWITCH" switchmd >dswitchm'

call examine 'spine:  SWITCH_M 599  1';
call examine '\       DSWITCHM 1000 2';
summary.3 = ''
summary.4 = ''

/*------------------------------------------------------------- */
/* split switch_d into logfiles for each testcase in VDM group  */
/*------------------------------------------------------------- */
'grep "flt002"   switchmd >flt002'
'grep "flt004"   switchmd >flt004'
'grep "flt005"   switchmd >flt005'
'grep "flt009"   switchmd >flt009'
'grep "flt010"   switchmd >flt010'
'grep "flt012"   switchmd >flt012'
'grep "flt013"   switchmd >flt013'
'grep "flt015"   switchmd >flt015'
'grep "flt016"   switchmd >flt016'
'grep "flt017"   switchmd >flt017'
'grep "flt018"   switchmd >flt018'
'grep "VVDCHRIO" switchmd >VVDCHRIO'

call examine 'vdm:    FLT002   1000  5'
call examine '\       FLT004   1000  6'
call examine '\       FLT005   1000  7'
call examine '\       FLT009   1000  8'
call examine '+       FLT010   1000  9'
call examine '\       FLT012   1000 10'
call examine '\       FLT013   1000 11'
call examine '\       FLT015   1000 12'
call examine '+       FLT016   1000 13'
call examine '\       FLT017   1000 14'
call examine '\       FLT018   1000 15'
call examine '\       VVDCHRIO 1000 16'
call examine '+       MCLK     1000 17'
summary.18 = ''
summary.19 = ''
summary.20 = ''
call examine 'files:  FSCOPY01 1000 21'
call examine '\       FSCOPY02 1000 22'
call examine '\       FS32CPY1 1000 23'
call examine '\       FS32CPY2 1000 24'
call examine '+       FSDEL    1000 25'
call examine '\       FS32DEL1 1000 26'
call examine '\       FS32DEL2 1000 27'
call examine '\       FSDIR    1000 28'
call examine '+       FS32DIR1 1000 29'
call examine '\       FS32DIR2 1000 30'
call examine '\       FSLOCK01 1000 31'
call examine '\       FSLOCK02 1000 32'
call examine '+       FS32LOCK 1000 33'
call examine '\       FS32RAND 1000 34'
call examine '\       FS32SEQ  1000 35'
call examine '\       LSTHRD   1000 36'
call examine 'pipes:  NMPIPE1C 1000 37'
call examine '\       NMPIPE1S 2000 38'
call examine '\       NMPIPE02 2000 39'
call examine '\       NMPIPE03 1000 40'
call examine '+       NMPIPE04 1000 41'
call examine '\       PIPES01  1000 42'
call examine '\       PIPES02  1000 43'
call examine '\       PIPES03  1000 44'
call examine '+       BSEQMP   1000 45'
summary.46 = ''
summary.47 = ''
summary.48 = ''
call examine 'npx:    NPX01    1000 49'
call examine '\       NPX02    1000 50'
call examine '\       NPX03    1000 51'
summary.52 = ''
call examine 'pm/vid: VSPS32   1000 53'
call examine '\       LSDLL    1000 54'
call examine '\       GPIFLOOD 1000 55'
call examine '\       VSMAIN32 1000 56'
call examine '+       SWP32    1000 57'
call examine '\       GP232    1000 58'
call examine '\       CUBE32   1000 59'
call examine '\       WIND32   1000 60'
call examine '+       EXCEPT32 1000 61'
call examine '\       CLOCK32  1000 62'
call examine '\       CUBE     1000 63'
call examine '\       VIDEO    1000 64'
call examine 'memory: M32LCK   1000 65'
call examine '\       M32PAGE  1000 66'
call examine '\       M32SHR   1000 67'
call examine '\       M32SUB   1000 68'
call examine '+       MEMCODE  1000 69'
call examine '\       M32NAME  1000 70'
call examine '\       MEMFREE  1000 71'
call examine '\       MEMHUGE1 1000 72'
call examine '+       MEMHUGE2 1000 73'
call examine '\       MEMLOCK  1000 74'
call examine '\       MEMSEL   1000 75'
call examine '\       MEMSUB   1000 76'
call examine '+       MEMSUBGR 1000 77'
summary.78 = ''
summary.79 = ''
summary.80 = ''

call stream summary,'c','open write'
call lineout summary,'** Stress tests results log **'
call lineout summary,' '
do j0 = 1 to 80 by 4
   j1 = j0+1
   j2 = j1+1
   j3 = j2+1
   call lineout summary,summary.j0' 'summary.j1' 'summary.j2' 'summary.j3
end
call lineout summary,' '
call lineout summary,'STARTED:  'date_start'  'time_start'     Bay Number:'  Obay
call lineout summary,'FINISHED: 'date_end'  'time_end'         Release Level:'  Orelease
call lineout summary,'STRESS:   PASS'right(passed,8)'   FAIL'right(failed,5)'     PARTIAL'right(partial,6)'    MISSING'right(missing,5)
call stream summary, 'c', 'close'
if quiet = 0 then
  'type' summary

'md \logm1 >nul 2>nul'
'erase \logm1 <\text\yes.in >nul'

'copy *. \logm1 >nul'
'copy *.cmp \logm1 >nul'
'copy pcmmed01.sum \logm1 >nul'

'erase *.hlp <\text\yes.in >nul'
'erase *.hyd <\text\yes.in >nul'
'erase *.rom <\text\yes.in >nul'
'erase *.sys <\text\yes.in >nul'
'erase *.da1 <\text\yes.in >nul'
'erase *.dat <\text\yes.in >nul'
'erase *.cmp <\text\yes.in >nul'
'erase *.bin <\text\yes.in >nul'
'erase *.    <\text\yes.in >nul'

return

/**************************/
/*   SHARED LOG SECTION   */
/**************************/
examine:
procedure expose passed failed missing partial summary. time_start time_end date_start date_end
parse arg description file_name tail_len spot
time_text = 0
spot=strip(spot)
file_text = left(file_name,8)
if description = '\' then description = ''
  else description = left(description,8)

no_answer = 1

if stream(file_name,'c','open read') \= 'READY:' then do  /* is file usable  */
   summary.spot = description file_text 'MISSING'         /* if file cannot  */
   missing = missing + 1                                  /* be opened, then */
   return                                                 /* set MISSING and */
   end                                                    /* return.         */

/* FILE OPENED - CONTINUE TO PROCESS FILE */

file_size =  stream(file_name,'c','query size');        /* get the file size */

if file_name \= "SWITCH_M" then do
   if tail_len < file_size  then do                  /* if tail less than size  */
      call stream file_name,'c','seek <'tail_len     /* set to end less taillen */
      end
   end


do forever
   my_text = linein(file_name)

   if file_name = "SWITCH_M" then do
     if pos('starting at',my_text) > 0 then do
        parse var my_text parm S1 S2 S3 S4 time_in S5 date_start remainder
        tim_len = length(time_in) - 3;
        time_start = left(time_in, tim_len)
        end
     else
     if pos('stopping at',my_text) > 0 then do
        parse var my_text parm S1 S2 S3 S4 time_in S5 date_end remainder
        tim_len = length(time_in) - 3;
        time_end = left(time_in, tim_len)
        leave
        end
     end

   if file_name = "SWITCH_M" then do
     if pos('SWITCHER process is ending thru normal exit. rc =0',my_text) > 0 then do
        summary.spot = description file_text 'PASS   '
        passed = passed + 1
        end
     end

   if file_name = "DSWITCHM" then do
     if pos('final logging message',my_text) > 0 then do
        summary.spot = description file_text 'PASS   '
        passed = passed + 1
        leave
        end
     end

   if pos('STATUS', my_text) > 0 then do  /* status line on new tstcase logs */
      if pos('Fail 0 ', my_text) > 0 then do            /* no failures noted */
        summary.spot = description file_text 'PASS   '
        passed = passed + 1
        leave
        end
      else do
           summary.spot = description file_text '<FAIL> '
           failed = failed + 1
           leave
           end
      end

   /********/

   if pos('FAIL-ABORT', my_text) > 0 then do
      summary.spot = description file_text '<PASS> '
      passed = passed + 1
      leave
      end

   if pos('FAIL_ABORT', my_text) > 0 then do
      summary.spot = description file_text '<PASS> '
      passed = passed + 1
      leave
      end

   if pos('Window over', my_text) > 0 then do
      summary.spot = description file_text '<PASS> '
      passed = passed + 1
      leave
      end

   if pos(pass, my_text) > 0 | pos(shutdown, my_text) > 0 then do
      summary.spot = description file_text 'PASS   '
      passed = passed + 1
      leave
      end

   if pos("ALL DONE", my_text) > 0 then do
      summary.spot = description file_text 'PASS   '
      passed = passed + 1
      leave
      end


   if lines(file_name) = 0 then do
      summary.spot = description file_text 'PARTIAL'
      partial = partial + 1
      leave
      end
end        /* end of main do-forever loop */

call stream file_name,'c','close'                      /* Close file on exit */
return

INFO_PLEASE:
say '~[1;45;37m'
say 'ͻ'
say '   This command file examines the PCMMED01 output logfiles and         '
say '   produces a unified report.  Each logfile is assessed as either      '
say '   PASS, FAIL, PARTIAL, or MISSING.  The logfiles are categorized for  '
say '   display and the PASS/FAIL etc. totals are given at the bottom.      '
say '   The output display fills one screen and is saved as PCMMED01.SUM.   '
say '   Logs and summary files are moved to \LOGM1, summary remains in \LOG.'
say '                                                                       '
say '   PARAMETERS:  (release level appears on PASS/FAIL summary line.      '
say '                                                                       '
say '        PCMMED01  (optional) Log results for PCMMED01                  '
say '        Rnnnnnnn  (optional) OS/2 Release level                        '
say '        Q         (optional) echo off, no screen displays              '
say 'ͼ'
say '~[0;40;37m'
exit
