/* ************************************************************************* */
/* PCMLAB - "RUN.CMD"  STRESS Testcase - Sniff & Med02pr script runner       */
/*                                                                           */
/*  carried on: T:\PCMLAB\STRESS\CMD  &  W:\STRESS\CMD   (LAN Server)        */
/*                                                                           */
/*  Works at:   \LOG directory on testcase partition.                        */
/*                                                                           */
/*                                                                           */
/*  Uses OS2 environment variables to determine testcase drive.              */
/*                                                                           */
/*                                                                           */
/*  PURPOSE: Initiate testcase scripts (PCMSNIFF or PCMMED01)                */
/*           Call LOG.CMD to produce summary files, & copy to LAN if PCMLAB  */
/*                                                                           */
/*  parameter Rnnnnnnn  (opt'l) release number                               */
/*  parameter Bnnnnn    (opt'l) machine bay number                           */
/*  parameter X________ (opt'l) Script file to run ** DEFAULT IS PCMMED01 ** */
/* ------------------------------------------------------------------------- */
'cls'
say ''
'echo off'
/* ****************************SCAN ARGUMENT LIST*************************** */
arg arglist        /*----- This form translates all parms to upper case -----*/

release = 0
bay = 0
tstscrpt = 'PCMMED01'                      /* SET DEFAULT FOR PCMMED01 RUN   */

do while (arglist \= '')                 /* 'CASE' logic is controlled by    */
   parse var arglist parm remainder      /* first letter of each parameter;  */
   arglist = remainder                   /* longer entries may be used w/out */
   code = left(parm,1)                   /* harm except for bay & release #s */
   if code = '?' then signal INFO_PLEASE
   if pos(code,'R') > 0 then do
      release = parm
      parse value parm with 'R' drvrlvl;   /* driver level from -R- parm */
      end
   else
      if pos(code,'B') > 0 then do
         bay = left(parm,6);
         end
   else
      if pos(code,'X') > 0 then do
         parse value parm with 'X' tstscrpt;    /* script file to execute */
         end
   else
      if code \= '' then do
         say 'Parameter "'parm'" not used; enter "?" to see full parm list:'
         pull y
         if y = '?' then signal INFO_PLEASE
         end
end
/* ------------------------------------------------------------------------- */
if (release = 0) then do
   rellvl  = value('PCM_RELLVL',,'OS2ENVIRONMENT');    /* get release level  */
   drvrlvl = rellvl
   release = 'R'||rellvl
   end
/* ------------------------------------------------------------------------- */
os2drv = value('PCM_BOOTDRV',,'OS2ENVIRONMENT');       /* get OS2 boot drive */
tstdrv = value('PCM_TESTDRV',,'OS2ENVIRONMENT');       /* get testcase drive */
if pos(os2drv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '~[1;09;41m ***************************************************************~[0;40;37m'
   say '~[1;09;41m * OS2 environment variable PCM_BOOTDRV not set.  Run PCMSETUP *~[0;40;37m'
   say '~[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *~[0;40;37m'
   say '~[1;09;41m ***************************************************************^~[0;40;37m'
   exit
   end
if pos(tstdrv,'CDEFGHIJKLMNOPQRSTUVWXYZ') = 0 then do
   say '~[1;09;41m ***************************************************************~[0;40;37m'
   say '~[1;09;41m * OS2 environment variable PCM_TESTDRV not set.  Run PCMSETUP *~[0;40;37m'
   say '~[1;09;41m * to update config.sys, then shutdown & reboot to continue.   *~[0;40;37m'
   say '~[1;09;41m ***************************************************************~[0;40;37m'
   exit
   end

/* ************************************************************************* */
/* Validate that the script file entered exists in the \script directory.    */
/* ************************************************************************* */
if stream(tstdrv':\script\'tstscrpt,'c','query exists') = '' then do
   signal SCRIPT_PROB
   end

/* ************************************************************************* */
/* IF LOGON ID FOUND FOR PCM001->PCM800 IN STARTUP.CMD - THEN CHECK FOR A    */
/* DIRECTORY THAT MATCHES THE DRIVER LEVEL ON THE PCMLAB LOGFILE SERVER      */
/* IF PCMLAB-LAN SETUP, AND DRIVER INCORRECT OR NOT FOUND ON SERVER ...ERROR */
/*      MUST VALIDATE HERE BEFORE EXECUTION AND LOGGING FUNCTIONS BEGIN      */
/* ************************************************************************* */
pcmid = 0;
pcmidfnd = 0;
filename = os2drv':\startup.cmd';
x=stream(filename,'c','open read');
do forever;
   line = linein(filename);
   if pos('LOGON PCM', line) > 0 then do
      parse value line with 'LOGON PCM' unused;
      pcmid = left(unused,3)                 /* set pcmid to labloc# w/o PCM */
      pcmidfnd = 1;
      leave
      end
   else
      if pos('logon pcm', line) > 0 then do
         parse value line with 'logon pcm' unused;
         pcmid = left(unused,3)              /* set pcmid to labloc# w/o PCM */
         pcmidfnd = 1;
         leave
         end
   if lines(filename) = 0 then leave
end
x=stream(filename,'c','close')
/* ------------------------------------------------------------------------- */
if pcmidfnd = 1 then do                        /* if PCMID found - LAN setup */
   if stream('z:\'drvrlvl,'c','query size') >= 0 then do
        signal chkbay
        end
   else do
        signal LAN_INFO
        end
   end
/* ************************************************************************* */
/* ----------CHECK BAY NUMBER - IF NONE PROVIDED - SET TO DEFAULT----------- */
/* ************************************************************************* */
chkbay:
   /* ---------------------------------------------------------------------- */
   /* if no BAY given as parm, default to B99001, and skip to next section.  */
   /* ---------------------------------------------------------------------- */
   if bay = 0 then do
      bay = 'B99001'
      signal chkpath
      end
   /* ---------------------------------------------------------------------- */

chkpath:
/* ************************************************************************* */
/* -- CHECK CONFIG.SYS LIBPATH, PATH, DPATH, LOCKER.SYS, LOCK32.SYS      --- */
/* --    TO VERIFY THAT PCMSETUP HAS BEEN DONE.                          --- */
/* ************************************************************************* */
xlocker = 0; xlock32 = 0;
xlibpath = 0; xpath = 0; xdpath = 0;
filename = os2drv':\config.sys';
x=stream(filename,'c','open read');
/*------------------------------------- */
do forever;
   pathline = linein(filename);
   if pos('LIBPATH', pathline) > 0 then do
      if pos(tstdrv':\STRESS;'tstdrv':\UTIL',pathline) > 0 then xlibpath = 1;
      end
   else
   if pos('SET PATH', pathline) > 0 then do
      if pos(tstdrv':\STRESS;'tstdrv':\CMD;'tstdrv':\UTIL;'tstdrv':\TEXT',pathline) > 0 then xpath = 1;
      end
   else
   if pos('SET DPATH', pathline) > 0 then do
      if pos(tstdrv':\STRESS;'tstdrv':\CMD;'tstdrv':\SCRIPT;'tstdrv':\TEXT',pathline) > 0 then xdpath = 1;
      end
   else do
        if pos('LOCKER.SYS', pathline) > 0 then xlocker = 1
        if pos('LOCK32.SYS', pathline) > 0 then xlock32 = 1
        end
   if lines(filename) = 0 then leave
end
/*------------------------------------- */
if xlibpath = 0 then signal pathprob
if xpath    = 0 then signal pathprob
if xdpath   = 0 then signal pathprob
if xlocker  = 0 then signal pathprob
if xlock32  = 0 then signal pathprob

/* ************************************************************************* */
/* -- NOW CHECK ACTIVE PATH AND DPATH TO VERIFY THAT SYSTEM WAS REBOOTED --- */
/* --    AFTER PCMSETUP, AND BEFORE TRYING TO RUN TESTCASES.             --- */
/* ************************************************************************* */
xactpath = 0; xactdpath = 0;
actpath  = value('PATH',,'OS2ENVIRONMENT');              /* get active PATH  */
actdpath = value('DPATH',,'OS2ENVIRONMENT');             /* get active DPATH */
if pos(tstdrv':\STRESS;'tstdrv':\CMD;'tstdrv':\UTIL;'tstdrv':\TEXT',actpath) > 0 then xactpath = 1;
if pos(tstdrv':\STRESS;'tstdrv':\CMD;'tstdrv':\SCRIPT;'tstdrv':\TEXT',actdpath) > 0 then xactdpath = 1;
/*-------------------------------------------------------------------------- */
if xactpath    = 0 then signal rbootprob
if xactdpath   = 0 then signal rbootprob

/* ************************************************************************* */
/* --Check STRESS directory, if all testcases for stress have been loaded -- */
/* --then the total number of lines below should be at least 140.         -- */
/* ************************************************************************* */
tstdrv':'
'cd \'
qname = RXQUEUE('Create')
call RXQUEUE 'Set',qname
'dir 'tstdrv':\stress | rxqueue 'qname
got_lines = queued()
call RXQUEUE 'Delete',qname
if got_lines < 140 then signal load_stress

/* ************************************************************************* */
/* EVERYTHING CHECKS OUT TO BEGIN STRESS TESTCASE EXECUTION.  DO IT....      */
/* ************************************************************************* */
call RXQUEUE 'Set', SESSION
/* ------------------------------------------------------------------------- */
rc = RXFUNCADD('SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs')
call SysLoadFuncs
/* ------------------------------------------------------------------------- */
tstdrv':'
if stream(tstdrv':\log','c','query size') >= 0 then signal START_TST
 else 'mkdir 'tstdrv':\log'

START_TST:
'cd \log'
'cls'
/* ------------------------------------------------------------------------- */
if tstscrpt = 'PCMMED01' then do          /* BLUE BAR FOR PCMMED01  */
   info = SysDriveInfo('A:')
   if info = '' then do
      say ''
      say '~[1;41;31m|||||||||||||||||||||||||||||||||||||||||||~[0;40;37m'
      say ''
      say '~[1;44;37mReady to run PCMMED01 test script..........~[0;40;37m'
      say ''
      say '~[1;44;37mInsert a scratch diskette in A:............~[0;40;37m'
      say ''
      say '~[1;44;37mMake sure diskette is not write protected..^~[0;40;37m'
      say ''
      say '~[1;41;31m|||||||||||||||||||||||||||||||||||||||||||~[0;40;37m'
      pause
      end
   end

/* ************************************************************************* */
/* --IF Running over NETVIEW, send testcase start message to NETVIEW server- */
if pcmidfnd = 1 then do
   'net send NVMESSAG "PCM'pcmid' beginning 'tstscrpt' testing."'
   end
/* ************************************************************************* */
/* -------- Erase all but  *.SUM  files from \LOG {current dir} ------------ */
'echo y | del *. *.cmp bin* >nul 2>nul'

/* ************************************************************************* */
/* ------------- Use ZAP to clear left over work directories. -------------- */
'zap 'tstdrv':\tmp    >nul 2>nul'
'zap 'tstdrv':\tmp1   >nul 2>nul'
'zap 'tstdrv':\tmp2   >nul 2>nul'
'zap 'tstdrv':\tmp3   >nul 2>nul'
'zap 'tstdrv':\tmp4   >nul 2>nul'
'zap 'tstdrv':\randir >nul 2>nul'
'zap 'tstdrv':\seqdir >nul 2>nul'

/* ************************************************************************* */
/* -------- Copy .hlp files from STRESS directory for execution ------------ */
'copy 'tstdrv':\stress\*.hlp'

/* ************************************************************************* */
/* For SNIFF clear LOGS, MED01 clear LOGM1 before test begins.  After, call  */
/* LOG to process test results and produce pcmsniff.sum or pcmmed01.sum      */
/* ------------------------------------------------------------------------- */
if tstscrpt = 'PCMSNIFF' then do
   if stream(tstdrv':\LOGS','c','query size') >= 0 then do
      'zap 'tstdrv':\LOGS >nul 2>nul'
      end
   'switch -l5 -v5 -o -u'tstdrv':\script\'tstscrpt' -fSWITCH_S'
   call SysSleep 90;
   'erase flt*.dat'
   'erase flt*.da1'
   'erase flt*.001'
   'erase flt*.002'
   'erase flt*.003'
   'erase flt*.rom'
   'erase flt*.hyd'
   'erase flt*.sys'
   'erase *.hlp'
   'attrib -r -h -s *.*'
   'call log Q PCMSNIFF' release bay
   if pcmidfnd = 1 then do                                /* LAN BASED SETUP */
      'copy pcmsniff.sum z:\'drvrlvl'\pcmsniff.'pcmid' >nul'
      end
   end
else
   if tstscrpt = 'PCMMED01' then do
      if stream(tstdrv':\LOGM1','c','query size') >= 0 then do
         'zap 'tstdrv':\LOGM1 >nul 2>nul'
         end
      'switch -l5 -v5 -o -u'tstdrv':\script\'tstscrpt' -fSWITCH_M'
      call SysSleep 90;
      'erase flt*.dat'
      'erase flt*.da1'
      'erase flt*.001'
      'erase flt*.002'
      'erase flt*.003'
      'erase flt*.rom'
      'erase flt*.hyd'
      'erase flt*.sys'
      'erase *.hlp'
      'attrib -r -h -s *.*'
      'call log Q PCMMED01' release bay
      if pcmidfnd = 1 then do                             /* LAN BASED SETUP */
      'copy pcmmed01.sum z:\'drvrlvl'\pcmmed01.'pcmid' >nul'
         end
      end
   else do
        tchar = left(tstscrpt,1)
        'switch -l5 -v5 -o -u'tstdrv':\script\'tstscrpt' -fSWITCH_'tchar
        end

'echo on'
/* ************************************************************************* */
/* IF Running over NETVIEW, send testcase finished message to NETVIEW server */
/* ************************************************************************* */
if pcmidfnd = 1 then do
   'net send NVMESSAG "PCM'pcmid' finished  'tstscrpt' testing."'
   end

/* **** USE GREP TO GENERATE A CAPSULE SUMMARY OF HOW THE TEST(s) WENT **** */
'cls'
'grep ELAPSED *.sum'
'grep FAIL *.sum'
exit

/* ************************************************************************* */
SCRIPT_PROB:
say '~[1;09;41mͻ'
say ' Parameter X________ Testcase SCRIPT name is INVALID                  '
say '                                                                      '
say ' Script name not found under \SCRIPT directory on testcase partition  '
say '                                                                      '
say ' Check \SCRIPT directory for available testcase script files.         '
say '                                                                      '
say ' Re-enter "run" command with valid/available script name.             '
say 'ͼ^~[0;40;37m'
exit

/* ************************************************************************* */
PATHPROB:
  say '~[1;09;41mͻ'
  say ' *** CONFIG.SYS IS NOT SETUP CORRECTLY FOR TESTCASE EXECUTION *** '
  say '                                                                  '
  say ' You will need to run PCMSETUP (if CDROM testkit install), or     '
  say ' run the SETUP diskette (if Diskette testkit install) in order    '
  say ' to copy required files to the OS2 boot drive and update the      '
  say ' CONFIG.SYS, AUTOEXEC.BAT, and STARTUP.CMD for PCM Testcases.     '
  say '                                                                  '
  say ' Then shutdown and reboot the system for PCM Testcase execution.  '
  say 'ͼ^~[0;40;37m'
  exit

/* ************************************************************************* */
RBOOTPROB:
  say '~[1;09;41mͻ'
  say ' *** CONFIG.SYS WAS SETUP CORRECTLY, BUT SYSTEM WAS NOT *** '
  say '     REBOOTED PRIOR TO ATTEMPTING TESTCASE EXECUTION.       '
  say '                                                            '
  say ' SHUTDOWN and REBOOT the system to activate the changes in  '
  say ' config.sys for PCM Testcase execution.                     '
  say 'ͼ^~[0;40;37m'
  say ''
  exit

/* ************************************************************************* */
LOAD_STRESS:
  say '~[1;09;41mͻ'
  say ' ** STRESS DIRECTORY NOT SHOWING CORRECT NUMBER OF FILES **  '
  say '                                                             '
  say ' You need to run PCMSETUP (CDROM testcase install) or        '
  say ' DLOADS.CMD (Diskette testcase install) to load the          '
  say ' files needed for STRESS testcase execution.                 '
  say 'ͼ^~[0;40;37m'
  exit

/* ************************************************************************* */
LAN_INFO:
say '~[1;09;41mͻ'
say ' Problem with OS/2 Driver Level supplied with PCMLAB LAN ENVIRONMENT  '
say ' for LAN BASED Testing:   Check following - correct as required:      '
say '                                                                      '
say '    - Attempt to use LAN BASED TESTING without LAN access active.     '
say '       re-run s.cmd for standalone testing                           '
say '       run D:\LANINST\INSTALL\INSTLS30 to active PCMLAB LAN access   '
say '                                                                      '
say '    - Invalid driver level supplied (examples:  6n.307  or 6.488).    '
say '       re-enter run command with correct driver level                '
say '                                                                      '
say '    - Directory for driver level not found on LAN drive "Y"           '
say '       NOTIFY PCM LAB TEAM LEAD - DRIVER SETUP FOR LAN NEEDED        '
say 'ͼ^~[0;40;37m'
exit

/* ************************************************************************* */
INFO_PLEASE:
say '~[1;45;37mͻ'
say ' RUN.CMD uses the following arguments:                                '
say '                                                                      '
say ' Rnnnnnnn   (optional) release number                                 '
say ' Bnnnnn     (optional) machine bay number                             '
say ' X________  (optional) testcase script to run  ** DEFAULT PCMMED01 ** '
say '                                                                      '
say ' Uses OS/2 environment variables to determine testcase drive.         '
say '                                                                      '
say ' EXAMPLES:                                                            '
say '   run                       --   run xpcmsniff                       '
say '   run r2.1 b299 xpcmmed01   --   run r2.11 xpcmsniff                 '
say '                                                                      '
say ' When testcase scripts are finished, a summary report is produced by  '
say ' giving PASS/FAIL/etc. results for each testcase in script.           '
say 'ͼ^~[0;40;37m'
exit
