/* ------------------------------------------------------------------------- */
/* PCMLAB - "STRLOG.CMD"  STRESS Testcase - Sniff & Med01 Results ReAnalyzer */
/*                                                                           */
/*  carried on: T:\PCMLAB\STRESS\CMD  &  W:\STRESS\CMD   (LAN Server)        */
/*                                                                           */
/*  PURPOSE: ReExamine contents of \LOG directory;  Log results of SNIFF or  */
/*           MED01 execution & move files to \LOGS (SNIFF) or \LOGM1 (MED01) */
/*                                                                           */
/*          Compress the various log files into a one-screen SUMMARY with    */
/*          counts for PASS, FAIL, PARTIAL, and MISSING test results.        */
/*                                                                           */
/*  parameter PCMSNIFF  (req'd) Log results for PCMSNIFF or PCMMED01         */
/*            PCMMED01                                                       */
/*                                                                           */
/*  parameter Rnnnnnnn  (opt'l) Release designation                          */
/*  parameter Q         (opt'l) quiet run, no screen displays                */
/* ------------------------------------------------------------------------- */
'cls'
say ''

parse arg arglist    /*-- This form leaves parms in mixed case as entered --*/
logtest = ''
release = 0          /* set defaults for optional parameters */
quiet = 0
do while (arglist \= '')                  /* 'CASE' logic is controlled by  */
   parse var arglist parm remainder       /* first letter of each parameter */
   arglist = remainder
   code = left(parm,1)
   if code = '?' then signal INFO_PLEASE
   if pos(code,'Qq') >0  then quiet = 1
   else
      if parm = 'PCMMED01' then logtest = 'PCMMED01'
   else
      if parm = 'pcmmed01' then logtest = 'PCMMED01'
   else
      if pos(code,'Rr') > 0 then release = parm
   else
      if code \= '' then do
         say 'Parameter "'parm'" not used; enter "?" to see full parm list:'
         pull y
         if y = '?' then signal INFO_PLEASE
         end
end

logtest = 'PCMMED01'

/* ------------------------------------------------------------------------- */
if (release = 0) then do
   rellvl  = value('PCM_RELLVL',,'OS2ENVIRONMENT');    /* get release level  */
   release = 'R'||rellvl
   end
Orelease = right(release,length(release) -1);

/* ------------------------------------------------------------------------- */
if quiet then 'echo off'

/*---------------------------------------------------------------------- */
/*--CALL ROUTINE FOR SNIFF OR STRESS, BASED ON PARAMETER FROM RUN.CMD---- */
/*------------------------------------------------------------------------- */
call LOG_MED01

'echo on'

exit


/*************************/
/*   MED01 LOG SECTION   */
/*************************/
LOG_MED01:
procedure expose release Orelease
summary='PCMMED01.SUM';
'cd  \log'                    /* get to log directory          */
'del \log\'summary' 2>nul'    /* erase old .SUM file in \log   */
'del \logm1\'summary' 2>nul'  /* erase old .SUM file in \logm1 */
'xcopy * \logm1  >nul'        /* copy new logfiles to \logm1 with rest */
'xcopy \logm1\*  >nul'        /* copy all logfiles from \logm1 to \log */
'call log Q PCMMED01'         /* invoke log.cmd to process files */
return


INFO_PLEASE:
say '~[1;45;37m'
say 'ͻ'
say '   This command is used after running individual testcases from the    '
say '   STRESS testcase group after to re-verify a testcase that was flagged'
say '   as a FAIL in the .SUM file following regular stress run.            '
say '                                                                       '
say '   The new logfiles in the \log directory will be copied to either the '
say '   \logs (pcmsniff) or \logm1 (pcmmed01) directories to group them     '
say '   with other logfiles created by regular stress run.  Then all files  '
say '   are copied back to the \log directory and LOG.CMD is invoked.       '
say '                                                                       '
say '   PCMMED01 or PCMSNIFF - test results to process    Default PCMMED01  '
say '   Q                    - echo off, no screen displays                 '
say '   Rnnnnnnn             - Release designation (goes on summary line)   '
say 'ͼ'
say '~[0;40;37m'
exit
